@@ -150,10 +150,10 @@ def request(kw, step):
                 if len(form_dict) == 1:
                     for form_k, form_v in form_dict.items():
                         form_name = form_k.split("/")[-1]
-                form_data = MultipartEncoder(fields={'file': (form_name, open(form_k, 'rb'), form_v)})
-                form_headers = {'Content-Type': form_data.content_type}
-                http.r.headers.update(form_headers)
-                r = getattr(http.r, kw)(http.baseurl + url, data=form_data, timeout=timeout)
+                        form_data = MultipartEncoder(fields={'file': (form_name, open(form_k, 'rb'), form_v)})
+                        form_headers = {'Content-Type': form_data.content_type}
+                        http.r.headers.update(form_headers)
+                        r = getattr(http.r, kw)(http.baseurl + url, data=form_data, timeout=timeout)
             except:
                 logger.exception("***form can be only one Key-value***")
         else:
@@ -162,8 +162,20 @@ def request(kw, step):
         logger.info(f'BODY: {r.request.body}')
 
     elif kw in ('put', 'patch'):
-        r = getattr(http.r, kw)(http.baseurl + url,
-                                data=_data['data'], timeout=timeout, **data)
+        if 'binary' in data:
+            binary_dict = json2dict(data['binary'])
+            try:
+                if len(binary_dict) == 1:
+                    for binary_k, binary_v in binary_dict.items():
+                        binary_headers = {'Content-Type': binary_v}
+                        http.r.headers.update(binary_headers)
+                        with open(binary_k, 'rb') as binary_f:
+                            r = getattr(http.r, kw)(http.baseurl + url, data=binary_f, timeout=timeout)
+            except:
+                logger.exception("*** binary can be only one Key-value***")
+        else:
+            r = getattr(http.r, kw)(http.baseurl + url,
+                                    data=_data['data'], timeout=timeout, **data)
         logger.info(f'BODY: {r.request.body}')
 
     elif kw in ('delete', 'options'):
